##  (2023-10-10)

* chore: add LICENSE ([5a11117](https://github.com/sergerdn/py-bas-automation/commit/5a11117))
* chore(dev-ops): add github actions (#5) ([8d9a813](https://github.com/sergerdn/py-bas-automation/commit/8d9a813)), closes [#5](https://github.com/sergerdn/py-bas-automation/issues/5)
* chore(docs): add CHANGELOG.md (#7) ([019b239](https://github.com/sergerdn/py-bas-automation/commit/019b239)), closes [#7](https://github.com/sergerdn/py-bas-automation/issues/7)
* chore(docs): add PROMO.md ([fafdfae](https://github.com/sergerdn/py-bas-automation/commit/fafdfae))
* chore(docs): improve docstrings and comments (#8) ([16ad537](https://github.com/sergerdn/py-bas-automation/commit/16ad537)), closes [#8](https://github.com/sergerdn/py-bas-automation/issues/8)
* chore(docs): update README.md ([fe9c50c](https://github.com/sergerdn/py-bas-automation/commit/fe9c50c))
* chore(github-actions): improve GitHub actions (#6) ([d2ce67a](https://github.com/sergerdn/py-bas-automation/commit/d2ce67a)), closes [#6](https://github.com/sergerdn/py-bas-automation/issues/6)
* fix(github-actions): remove pr_agent.yml ([a5de23d](https://github.com/sergerdn/py-bas-automation/commit/a5de23d))
* feat: initial public release ([e7e479d](https://github.com/sergerdn/py-bas-automation/commit/e7e479d))
* feat(release): 0.1.0 ([0416a5c](https://github.com/sergerdn/py-bas-automation/commit/0416a5c))
* feat(release): 0.1.1 ([0096d26](https://github.com/sergerdn/py-bas-automation/commit/0096d26))
* first commit ([12ae24b](https://github.com/sergerdn/py-bas-automation/commit/12ae24b))



##  (2023-10-10)

* chore: add LICENSE ([5a11117](https://github.com/sergerdn/py-bas-automation/commit/5a11117))
* chore(dev-ops): add github actions (#5) ([8d9a813](https://github.com/sergerdn/py-bas-automation/commit/8d9a813)), closes [#5](https://github.com/sergerdn/py-bas-automation/issues/5)
* chore(docs): add CHANGELOG.md ([a808a6b](https://github.com/sergerdn/py-bas-automation/commit/a808a6b))
* chore(docs): add PROMO.md ([fafdfae](https://github.com/sergerdn/py-bas-automation/commit/fafdfae))
* chore(docs): update README.md ([fe9c50c](https://github.com/sergerdn/py-bas-automation/commit/fe9c50c))
* chore(github-actions): improve GitHub actions (#6) ([d2ce67a](https://github.com/sergerdn/py-bas-automation/commit/d2ce67a)), closes [#6](https://github.com/sergerdn/py-bas-automation/issues/6)
* feat: initial public release ([e7e479d](https://github.com/sergerdn/py-bas-automation/commit/e7e479d))
* feat(release): 0.1.0 ([0416a5c](https://github.com/sergerdn/py-bas-automation/commit/0416a5c))
* feat(release): 0.1.1 ([0096d26](https://github.com/sergerdn/py-bas-automation/commit/0096d26))
* first commit ([12ae24b](https://github.com/sergerdn/py-bas-automation/commit/12ae24b))



